@@ -3,7 +3,7 @@
 
 #############################################
 # File Name: word.py
-# Author: 程序员晚枫
+# 公众号/B站/小红书/抖音: 程序员晚枫
 # Mail: 1957875073@qq.com
 # Created Time:  2022-4-25 10:17:34
 # Description: 有关word的自动化操作
@@ -19,5 +19,9 @@ import poword
 # 自己指定路径，
 # 为了适配wps不能转换doc的问题，这里限定：只能转换docx
 # @except_dec()
+from office.lib.decorator_utils.instruction_url import instruction
+
+
+@instruction
 def docx2pdf(path):
     poword.docx2pdf(path)
